==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/lambda_code_signing_config/LambdaCodeSigningConfigPolicies.java <==
package com.hashicorp.cdktf.providers.aws.lambda_code_signing_config;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.542Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.lambdaCodeSigningConfig.LambdaCodeSigningConfigPolicies")
@software.amazon.jsii.Jsii.Proxy(LambdaCodeSigningConfigPolicies.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LambdaCodeSigningConfigPolicies extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUntrustedArtifactOnDeployment();

    /**
     * @return a {@link Builder} of {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaCodeSigningConfigPolicies> {
        java.lang.String untrustedArtifactOnDeployment;

        /**
         * Sets the value of {@link LambdaCodeSigningConfigPolicies#getUntrustedArtifactOnDeployment}
         * @param untrustedArtifactOnDeployment Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder untrustedArtifactOnDeployment(java.lang.String untrustedArtifactOnDeployment) {
            this.untrustedArtifactOnDeployment = untrustedArtifactOnDeployment;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaCodeSigningConfigPolicies}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LambdaCodeSigningConfigPolicies build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaCodeSigningConfigPolicies {
        private final java.lang.String untrustedArtifactOnDeployment;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.untrustedArtifactOnDeployment = software.amazon.jsii.Kernel.get(this, "untrustedArtifactOnDeployment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.untrustedArtifactOnDeployment = java.util.Objects.requireNonNull(builder.untrustedArtifactOnDeployment, "untrustedArtifactOnDeployment is required");
        }

        @Override
        public final java.lang.String getUntrustedArtifactOnDeployment() {
            return this.untrustedArtifactOnDeployment;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("untrustedArtifactOnDeployment", om.valueToTree(this.getUntrustedArtifactOnDeployment()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.lambdaCodeSigningConfig.LambdaCodeSigningConfigPolicies"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaCodeSigningConfigPolicies.Jsii$Proxy that = (LambdaCodeSigningConfigPolicies.Jsii$Proxy) o;

            return this.untrustedArtifactOnDeployment.equals(that.untrustedArtifactOnDeployment);
        }

        @Override
        public final int hashCode() {
            int result = this.untrustedArtifactOnDeployment.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/lambda_code_signing_config/LambdaCodeSigningConfigPolicies.java <==
package com.hashicorp.cdktf.providers.aws.lambda_code_signing_config;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.336Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.lambdaCodeSigningConfig.LambdaCodeSigningConfigPolicies")
@software.amazon.jsii.Jsii.Proxy(LambdaCodeSigningConfigPolicies.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LambdaCodeSigningConfigPolicies extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/lambda_code_signing_config#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getUntrustedArtifactOnDeployment();

    /**
     * @return a {@link Builder} of {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaCodeSigningConfigPolicies> {
        java.lang.String untrustedArtifactOnDeployment;

        /**
         * Sets the value of {@link LambdaCodeSigningConfigPolicies#getUntrustedArtifactOnDeployment}
         * @param untrustedArtifactOnDeployment Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/lambda_code_signing_config#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder untrustedArtifactOnDeployment(java.lang.String untrustedArtifactOnDeployment) {
            this.untrustedArtifactOnDeployment = untrustedArtifactOnDeployment;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaCodeSigningConfigPolicies}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LambdaCodeSigningConfigPolicies build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaCodeSigningConfigPolicies}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaCodeSigningConfigPolicies {
        private final java.lang.String untrustedArtifactOnDeployment;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.untrustedArtifactOnDeployment = software.amazon.jsii.Kernel.get(this, "untrustedArtifactOnDeployment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.untrustedArtifactOnDeployment = java.util.Objects.requireNonNull(builder.untrustedArtifactOnDeployment, "untrustedArtifactOnDeployment is required");
        }

        @Override
        public final java.lang.String getUntrustedArtifactOnDeployment() {
            return this.untrustedArtifactOnDeployment;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("untrustedArtifactOnDeployment", om.valueToTree(this.getUntrustedArtifactOnDeployment()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.lambdaCodeSigningConfig.LambdaCodeSigningConfigPolicies"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaCodeSigningConfigPolicies.Jsii$Proxy that = (LambdaCodeSigningConfigPolicies.Jsii$Proxy) o;

            return this.untrustedArtifactOnDeployment.equals(that.untrustedArtifactOnDeployment);
        }

        @Override
        public final int hashCode() {
            int result = this.untrustedArtifactOnDeployment.hashCode();
            return result;
        }
    }
}
